==> WeefPy-1.0.4.tar.gz: WeefPy-1.0.4/WeefPy/request.py <==
from urllib.parse import parse_qs
from http.cookies import SimpleCookie
from email.parser import BytesParser
from orjson import loads


class Request:
	def __init__(self, req):
		self._headers = req
		self.host = req["HTTP_HOST"]
		self.method = req["REQUEST_METHOD"]
		self.path = req["PATH_INFO"]
		self.query_string = parse_qs(req["QUERY_STRING"])
		self.data = None
		self.content_type = req.get("CONTENT_TYPE")
		self.content_length = int(req.get("CONTENT_LENGTH", 0))
		self._bad_request = False

		self.cookie = SimpleCookie()
		raw_cookie = req.get("HTTP_COOKIE")
		if raw_cookie:
			self.cookie.load(raw_cookie)

		if not self.content_length:
			return
		try:
			if self.content_type == "application/json":
				data = req["wsgi.input"].read(self.content_length)
				self.data = loads(data)
			elif self.content_type == "application/x-www-form-urlencoded" and self.content_length:
				data = parse_qs(req["wsgi.input"].read(self.content_length))
				self.data = {}
				for key in data:
					if len(data[key]) > 1:
						value = [item.decode() for item in data[key]]
					else:
						value = data[key][0].decode()
					self.data[key.decode()] = value
			elif self.content_length and self.content_type[0:20] == "multipart/form-data;":
				txt = b"Content-Type: " + self.content_type.encode() + b"\n" + req["wsgi.input"].read(self.content_length)
				m = BytesParser().parsebytes(txt)
				self.data = {
					p.get_param("name", header="content-disposition"): p.get_payload(decode=True) for p in m.get_payload()
				}
			else:
				self.data = req["wsgi.input"].read(self.content_length)
		except Exception:
			self._bad_request = True

	def get_header(self, key):
		return self._headers.get(key)  # "HTTP_" + key.upper() - useless - just follow conventions

	def get_bad_request(self):
		return self._bad_request

==> WeefPy-1.1.0.tar.gz: WeefPy-1.1.0/WeefPy/request.py <==
from urllib.parse import parse_qs
from http.cookies import SimpleCookie
from email.parser import BytesParser
from orjson import loads


class Request:
	def __init__(self, req):
		self._headers = req
		self.host = req["HTTP_HOST"]
		self.method = req["REQUEST_METHOD"]
		self.path = req["PATH_INFO"]
		self.query_string = parse_qs(req["QUERY_STRING"])
		self.data = None
		self.content_type = req.get("CONTENT_TYPE")
		self.content_length = int(req.get("CONTENT_LENGTH", 0))
		self._bad_request = False

		self.cookie = SimpleCookie()
		raw_cookie = req.get("HTTP_COOKIE")
		if raw_cookie:
			self.cookie.load(raw_cookie)

		if not self.content_length:
			return
		try:
			if self.content_type == "application/json":
				data = req["wsgi.input"].read(self.content_length)
				self.data = loads(data)
			elif self.content_type == "application/x-www-form-urlencoded":
				data = parse_qs(req["wsgi.input"].read(self.content_length))
				self.data = {}
				for key in data:
					if len(data[key]) > 1:
						value = [item.decode() for item in data[key]]
					else:
						value = data[key][0].decode()
					self.data[key.decode()] = value
			elif self.content_type[0:20] == "multipart/form-data;":
				txt = b"Content-Type: " + self.content_type.encode() + b"\n" + req["wsgi.input"].read(self.content_length)
				m = BytesParser().parsebytes(txt)
				self.data = {
					p.get_param("name", header="content-disposition"): p.get_payload(decode=True) for p in m.get_payload()
				}
			else:
				self.data = req["wsgi.input"].read(self.content_length)
		except Exception:
			self._bad_request = True

	def get_header(self, key):
		return self._headers.get(key)  # "HTTP_" + key.upper() - useless - just follow conventions

	def get_bad_request(self):
		return self._bad_request
